@@ -1,8 +1,9 @@
-use v5.14.0;
-package JMAP::Tester::Response::Paragraph 0.107;
+use v5.20.0;
+package JMAP::Tester::Response::Paragraph 0.108;
 # ABSTRACT: a group of sentences in a JMAP response
 
 use Moo;
+use experimental 'signatures';
 
 use JMAP::Tester::Abort 'abort';
 
@@ -24,8 +25,7 @@ use namespace::clean;
 #pod
 #pod =cut
 
-sub client_id {
-  my ($self) = @_;
+sub client_id ($self) {
   $self->_sentences->[0]->client_id;
 }
 
@@ -48,7 +48,7 @@ has sentences => (is => 'bare', reader => '_sentences', required => 1);
 #pod
 #pod =cut
 
-sub sentences { @{ $_[0]->_sentences } }
+sub sentences ($self) { @{ $self->_sentences } }
 
 #pod =method sentence
 #pod
@@ -58,8 +58,7 @@ sub sentences { @{ $_[0]->_sentences } }
 #pod
 #pod =cut
 
-sub sentence {
-  my ($self, $n) = @_;
+sub sentence ($self, $n) {
   abort("there is no sentence for index $n")
     unless $self->_sentences->[$n];
 }
@@ -77,15 +76,13 @@ sub sentence {
 #pod
 #pod =cut
 
-sub single {
-  my ($self, $name) = @_;
-
+sub single ($self, $name = undef) {
   my @sentences = $self->sentences;
 
-  Carp::confess("more than one sentence in set, but ->single called")
+  abort("more than one sentence in paragraph, but ->single called")
     if @sentences > 1;
 
-  Carp::confess("single sentence not of expected name <$name>")
+  abort("single sentence not of expected name <$name>")
     if defined $name && $name ne $sentences[0]->name;
 
   return $sentences[0];
@@ -100,9 +97,7 @@ sub single {
 #pod
 #pod =cut
 
-sub assert_n_sentences {
-  my ($self, $n) = @_;
-
+sub assert_n_sentences ($self, $n) {
   Carp::confess("no sentence count given") unless defined $n;
 
   my @sentences = $self->sentences;
@@ -123,10 +118,8 @@ sub assert_n_sentences {
 #pod
 #pod =cut
 
-sub sentence_named {
-  my ($self, $name) = @_;
-
-  Carp::confess("no name given") unless defined $name;
+sub sentence_named ($self, $name) {
+  Carp::confess("no sentence name given") unless defined $name;
 
   my @sentences = grep {; $_->name eq $name } $self->sentences;
 
@@ -151,12 +144,12 @@ sub sentence_named {
 #pod
 #pod =cut
 
-sub as_triples {
-  [ map {; $_->as_triple } $_[0]->sentences ]
+sub as_triples ($self) {
+  [ map {; $_->as_triple } $self->sentences ]
 }
 
-sub as_stripped_triples {
-  [ map {; $_->as_stripped_triple } $_[0]->sentences ]
+sub as_stripped_triples ($self) {
+  [ map {; $_->as_stripped_triple } $self->sentences ]
 }
 
 #pod =method as_pairs
@@ -166,12 +159,12 @@ sub as_stripped_triples {
 #pod
 #pod =cut
 
-sub as_pairs {
-  [ map {; $_->as_pair } $_[0]->sentences ]
+sub as_pairs ($self) {
+  [ map {; $_->as_pair } $self->sentences ]
 }
 
-sub as_stripped_pairs {
-  [ map {; $_->as_stripped_pair } $_[0]->sentences ]
+sub as_stripped_pairs ($self) {
+  [ map {; $_->as_stripped_pair } $self->sentences ]
 }
 
 1;
@@ -188,7 +181,7 @@ JMAP::Tester::Response::Paragraph - a group of sentences in a JMAP response
 
 =head1 VERSION
 
-version 0.107
+version 0.108
 
 =head1 OVERVIEW
 
